@@ -20,8 +20,12 @@
  * Boston, MA 02111-1307, USA.  
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "gdl-i18n.h"
 #include <gtk/gtknotebook.h>
-#include <libgnome/gnome-macros.h>
 
 #include "gdl-tools.h"
 #include "gdl-dock-notebook.h"
@@ -87,11 +91,13 @@ enum {
 
 /* ----- Private functions ----- */
 
-GNOME_CLASS_BOILERPLATE (GdlDockNotebook, gdl_dock_notebook, GdlDockItem, GDL_TYPE_DOCK_ITEM) ;
+GDL_CLASS_BOILERPLATE (GdlDockNotebook, gdl_dock_notebook, GdlDockItem, GDL_TYPE_DOCK_ITEM) ;
 
 static void
 gdl_dock_notebook_class_init (GdlDockNotebookClass *klass)
 {
+    static gboolean style_initialized = FALSE;
+    
     GObjectClass       *g_object_class;
     GtkObjectClass     *gtk_object_class;
     GtkWidgetClass     *widget_class;
@@ -121,7 +127,7 @@ gdl_dock_notebook_class_init (GdlDockNotebookClass *klass)
     object_class->present = gdl_dock_notebook_present;
     object_class->reorder = gdl_dock_notebook_reorder;
     
-    item_class->has_grip = TRUE;
+    item_class->has_grip = FALSE;
     item_class->set_orientation = gdl_dock_notebook_set_orientation;    
     
     g_object_class_install_property (
@@ -132,6 +138,18 @@ gdl_dock_notebook_class_init (GdlDockNotebookClass *klass)
                           0,
                           G_PARAM_READWRITE |
                           GDL_DOCK_PARAM_EXPORT | GDL_DOCK_PARAM_AFTER));
+
+    if (!style_initialized) {
+        style_initialized = TRUE;
+        
+        gtk_rc_parse_string (
+            "style \"gdl-dock-notebook-default\" {\n"
+            "xthickness = 2\n"
+            "ythickness = 2\n"
+            "}\n"
+            "widget_class \"*.GtkNotebook.GdlDockItem\" "
+            "style : gtk \"gdl-dock-notebook-default\"\n");
+    }
 }
 
 static void 
@@ -168,10 +186,7 @@ gdl_dock_notebook_instance_init (GdlDockNotebook *notebook)
     /* create the container notebook */
     item->child = gtk_notebook_new ();
     gtk_widget_set_parent (item->child, GTK_WIDGET (notebook));
-    if (item->orientation == GTK_ORIENTATION_HORIZONTAL)
-        gtk_notebook_set_tab_pos (GTK_NOTEBOOK (item->child), GTK_POS_TOP);
-    else
-        gtk_notebook_set_tab_pos (GTK_NOTEBOOK (item->child), GTK_POS_LEFT);
+    gtk_notebook_set_tab_pos (GTK_NOTEBOOK (item->child), GTK_POS_BOTTOM);
     g_signal_connect (item->child, "switch_page",
                       (GCallback) gdl_dock_notebook_switch_page_cb, (gpointer) item);
     g_signal_connect (item->child, "notify::page",
@@ -236,7 +251,7 @@ gdl_dock_notebook_destroy (GtkObject *object)
 
     /* we need to call the virtual first, since in GdlDockDestroy our
        children dock objects are detached */
-    GNOME_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+    GDL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
 
     /* after that we can remove the GtkNotebook */
     if (item->child) {
@@ -253,7 +268,7 @@ gdl_dock_notebook_switch_page_cb (GtkNotebook     *nb,
 {
     GdlDockNotebook *notebook;
     GtkWidget       *tablabel;
-
+    
     notebook = GDL_DOCK_NOTEBOOK (data);
 
     /* deactivate old tablabel */
@@ -305,7 +320,7 @@ gdl_dock_notebook_forall (GtkContainer *container,
 
     if (include_internals) {
         /* use GdlDockItem's forall */
-        GNOME_CALL_PARENT (GTK_CONTAINER_CLASS, forall, 
+        GDL_CALL_PARENT (GTK_CONTAINER_CLASS, forall, 
                            (container, include_internals, callback, callback_data));
     }
     else {
@@ -368,19 +383,24 @@ gdl_dock_notebook_dock (GdlDockObject    *object,
         else {
             GdlDockItem *item = GDL_DOCK_ITEM (object);
             GdlDockItem *requestor_item = GDL_DOCK_ITEM (requestor);
+            gchar       *name;
             GtkWidget   *label;
             gint         position = -1;
             
             label = gdl_dock_item_get_tablabel (requestor_item);
             if (!label) {
-                label = gdl_dock_tablabel_new (requestor_item);
+                g_object_get (requestor_item, "long_name", &name, NULL);
+                label = gtk_label_new (name);
+                g_free (name);
                 gdl_dock_item_set_tablabel (requestor_item, label);
             }
+#if 0
             if (GDL_IS_DOCK_TABLABEL (label)) {
                 gdl_dock_tablabel_deactivate (GDL_DOCK_TABLABEL (label));
                 /* hide the item grip, as we will use the tablabel's */
                 gdl_dock_item_hide_grip (requestor_item);
             }
+#endif
 
             if (other_data && G_VALUE_HOLDS (other_data, G_TYPE_INT))
                 position = g_value_get_int (other_data);
@@ -392,7 +412,7 @@ gdl_dock_notebook_dock (GdlDockObject    *object,
         }
     }
     else
-        GNOME_CALL_PARENT (GDL_DOCK_OBJECT_CLASS, dock,
+        GDL_CALL_PARENT (GDL_DOCK_OBJECT_CLASS, dock,
                            (object, requestor, position, other_data));
 }
 
@@ -407,7 +427,7 @@ gdl_dock_notebook_set_orientation (GdlDockItem    *item,
             gtk_notebook_set_tab_pos (GTK_NOTEBOOK (item->child), GTK_POS_LEFT);
     }
 
-    GNOME_CALL_PARENT (GDL_DOCK_ITEM_CLASS, set_orientation, (item, orientation));
+    GDL_CALL_PARENT (GDL_DOCK_ITEM_CLASS, set_orientation, (item, orientation));
 }
 
 static gboolean 
@@ -452,7 +472,7 @@ gdl_dock_notebook_present (GdlDockObject *object,
     if (i >= 0)
         gtk_notebook_set_current_page (GTK_NOTEBOOK (item->child), i);
 
-    GNOME_CALL_PARENT (GDL_DOCK_OBJECT_CLASS, present, (object, child));
+    GDL_CALL_PARENT (GDL_DOCK_OBJECT_CLASS, present, (object, child));
 }
 
 static gboolean 
